@@ -1,5 +1,6 @@
 #!/bin/bash
-# use the actual perl from the Makefile (perld, perl5.11.0, ...)
+# use the actual perl from the Makefile (perl5.8.8, 
+# perl5.10.0d-nt, perl5.11.0, ...)
 PERL=`grep "^PERL =" Makefile|cut -c8-`
 PERL=${PERL:-perl}
 # if $] < 5.9 you may want to remove -Mblib
@@ -25,9 +26,12 @@ function ctest {
     else
       o="ccode$n"
     fi
-    if [ -z "$str" ]; then 
+    if [ -z "$str" ]; then
+        if [ "$n" = "08" ]; then n=8; fi 
+        if [ "$n" = "09" ]; then n=9; fi
 	echo "${tests[${n}]}" > ${o}.pl
-    else 
+        str="${tests[${n}]}"
+    else
 	echo "$str" > ${o}.pl
     fi
     echo ${OCMD}-o$o.c $o.pl
@@ -37,7 +41,11 @@ function ctest {
     echo $CCMD $o.c $LCMD -o $o
     $CCMD $o.c $LCMD -o $o
     test -x $o || exit
-    ./$o || exit
+    #echo "./$o"
+    res=$(./$o) || exit
+    #echo "$res"
+    test "X$res" = "X${result[$n]}" || echo "./$o failed. Got: '$res', expected: '${result[$n]}'"
+    test "X$res" = "X${result[$n]}" && echo "./$o ok. '$str' => '$res'"
 }
 
 declare -a tests[19]
@@ -47,11 +55,11 @@ result[1]='hi';
 tests[2]="for (1,2,3) { print if /\d/ }"
 result[2]='123';
 tests[3]='$_ = "xyxyx"; %j=(1,2); s/x/$j{print("z")}/ge; print $_'
-result[3]='hi';
+result[3]='zzz2y2y2';
 tests[4]='$_ = "xyxyx"; %j=(1,2); s/x/$j{print("z")}/g; print $_'
-result[4]='zzz2y2y2';
+result[4]='z2y2y2';
 tests[5]='split /a/,"bananarama"; print @_'
-result[5]='z2y2y2';
+result[5]='bnnrm';
 tests[6]="{package P; sub x {print 'ya'} x}"
 result[6]='ya';
 tests[7]='@z = split /:/,"b:r:n:f:g"; print @z'
@@ -97,7 +105,8 @@ if [ -n "$1" ]; then
     shift
   done
 else
-  for b in $(seq 19); do
+  for b in $(seq -f"%02.0f" 19); do
+  #for b in $(seq 19); do
     ctest $b
   done
 fi
@@ -109,3 +118,10 @@ fi
 
 #All: Undefined subroutine &main::a called at ccode8.pl line 1.
 #ctest 8 'sub AUTOLOAD { print 1 } &{"a"}()'
+
+#  for $k (sort { length $ENV{$b} <=> length $ENV{$a} } keys %ENV) {
+# 	print "$k=$ENV{$k}\n";
+#  }
+
+#  http://www.nntp.perl.org/group/perl.perl5.porters/2005/07/msg103315.html
+#  fail for B::CC should be covered by test 18
